IndoorManager class
Manager for handling indoor navigation and floor switching logic.
Constructors
- IndoorManager(PowerMapController controller)
Properties
- controller → PowerMapController
-
final
- currentFloor → int?
-
no setter
- currentVenue → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getActiveVenue(
) → Future< Map< String, dynamic> ?> - Gets the currently active venue geojson data.
-
getBuildings(
) → Future< List< Map< >String, dynamic> > - Gets all buildings from the loaded geometry.
-
getFloorInfo(
int ordinal) → Future< Map< String, dynamic> ?> - Gets detailed information about a specific floor level.
-
getVenueInfo(
[String? venueId]) → Future< Map< String, dynamic> ?> - Gets detailed info about a venue including its available floors.
-
getVenues(
) → Future< List< Map< >String, dynamic> > - Gets all venues from the loaded geometry.
-
loadIndoorMap(
String venueId, {int initialFloor = 0, bool fitBounds = true, bool animate = true}) → Future< void> - Load a venue and switch map filtering to its initial floor.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setFloor(
int level, {bool animate = true}) → Future< void> - Sets the current floor to be rendered by the map geometry.
-
toString(
) → String -
A string representation of this object.
inherited
-
unloadIndoorMap(
) → Future< void> - Unload current indoor map and remove filtering.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited