clearMarkers method
Removes all symbol markers and circles from the map.
Implementation
Future<void> clearMarkers() async {
await _controller.clearSymbols();
await _controller.clearCircles();
}
Removes all symbol markers and circles from the map.
Future<void> clearMarkers() async {
await _controller.clearSymbols();
await _controller.clearCircles();
}