widgetMarkers property
Notifies the PowerMap widget when the list of custom widget markers changes.
Implementation
final ValueNotifier<List<PowerWidgetMarker>> widgetMarkers = ValueNotifier(
[],
);
Notifies the PowerMap widget when the list of custom widget markers changes.
final ValueNotifier<List<PowerWidgetMarker>> widgetMarkers = ValueNotifier(
[],
);