PowerMapOfflineManager class

ตัวจัดกาแผนที่สำหรับโหลดข้อมูลพิกัดล่วงหน้า (Smart Pre-loading) เพื่อให้กระบวนการเลื่อนแผนที่ลื่นไหลแบบ Offline / Cache คล้าย OsmAnd

Constructors

PowerMapOfflineManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

downloadRegion({required LatLngBounds bounds, required String styleKey, double minZoom = 10.0, double maxZoom = 16.0, String regionName = 'powermap_offline'}) Future<void>
ฟังก์ชันสำหรับดาวน์โหลดแผนที่ล่วงหน้า (Pre-load/Offline Region) ท่านสามารถกำหนดช่วง bounds ที่ต้องการโหลดเพื่อเก็บลง Cache เครื่องได้ แผนที่บริเวณนี้จะประมวลผลวาดด้วย GPU ทันทีโดยไม่ต้องรอเน็ต