PowerRouteStep class

Constructors

PowerRouteStep({required String text, required double distance, required double duration, required LatLng location, List<PowerRouteVoiceInstruction> voiceInstructions = const []})

Properties

distance double
final
distanceStr String
no setter
duration double
final
hashCode int
The hash code for this object.
no setterinherited
location LatLng
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
voiceInstructions List<PowerRouteVoiceInstruction>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited