PowerWidgetMarker class

A model representing a Flutter Widget to be displayed as a marker on the map.

Constructors

PowerWidgetMarker({required LatLng position, required Widget widget, String? id, Alignment alignment = Alignment.center})

Properties

alignment Alignment
Alignment of the widget relative to the anchor point.
final
hashCode int
The hash code for this object.
no setterinherited
id String?
Optional unique ID for management.
final
position LatLng
The geographic coordinate where the widget should be pinned.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget Widget
The Flutter widget to render at this position.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited