currentLocation property
Notifier that emits the latest location. Emits null when tracking is stopped or no location is found.
Implementation
final ValueNotifier<Position?> currentLocation = ValueNotifier(null);
Notifier that emits the latest location. Emits null when tracking is stopped or no location is found.
final ValueNotifier<Position?> currentLocation = ValueNotifier(null);