NavigationState class

Constructors

factory

Properties

cameraTilt double
final
currentPosition LatLng
final
currentStepIndex int
final
distanceAlongStep double
final
distanceToNextManeuver double
final
estimatedArrivalTime DateTime?
final
hasArrived bool
final
hashCode int
The hash code for this object.
no setterinherited
instructionText String
final
isFollowModeEnabled bool
final
isOffRoute bool
final
isRerouting bool
final
isSimulationPaused bool
final
maneuverType String?
final
mode PowerNavigationMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simulationMultiplier double
final
speedLimit double?
final
speedLimitResult SpeedLimitResult?
final
speedMps double
final
totalRemainingDistance double
final
totalRemainingDuration double
final
vehicleBearing double
final
vehiclePosition LatLng
final

Methods

copyWith({LatLng? currentPosition, LatLng? vehiclePosition, double? vehicleBearing, double? speedMps, int? currentStepIndex, double? distanceAlongStep, double? distanceToNextManeuver, double? totalRemainingDistance, double? totalRemainingDuration, String? instructionText, bool? isOffRoute, bool? isRerouting, String? maneuverType, bool? isSimulationPaused, double? simulationMultiplier, bool? isFollowModeEnabled, PowerNavigationMode? mode, bool? hasArrived, DateTime? estimatedArrivalTime, double? cameraTilt, double? speedLimit, SpeedLimitResult? speedLimitResult}) NavigationState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited