didChangeAppLifecycleState method

  1. @override
void didChangeAppLifecycleState(
  1. AppLifecycleState state
)
override

Called when the system puts the app in the background or returns the app to the foreground.

An example of implementing this method is provided in the class-level documentation for the WidgetsBindingObserver class.

This method exposes notifications from SystemChannels.lifecycle.

See also:

Implementation

@override
void didChangeAppLifecycleState(AppLifecycleState state) {
  if (stateNotifier.value == null) return;

  debugPrint('[NAV_LIFECYCLE] AppLifecycleState changed: $state');

  if (state == AppLifecycleState.paused || state == AppLifecycleState.inactive) {
    _lastTime = null;
    _lastGpsUpdateTime = null;
  } else if (state == AppLifecycleState.resumed) {
    _handleAppResumed();
  }
}