initialize static method
void
initialize({})
Initializes the PowerMap SDK with the required credentials.
The mapApiKey is used for map tiles and base layers.
The clientId and clientSecret are used to authenticate with backend services (e.g., Routing).
Optional baseUrl can be provided to point to a different environment.
Implementation
static void initialize({
required String mapApiKey,
required String clientId,
required String clientSecret,
String? baseUrl,
}) {
_mapApiKey = mapApiKey;
_clientId = clientId;
_clientSecret = clientSecret;
if (baseUrl != null) _baseUrl = baseUrl;
}