editGeoJsonUrl method

Future<bool> editGeoJsonUrl(
  1. String id,
  2. String url
)

Edits a GeoJSON source with a new URL.

The id specifies the source identifier, and url contains the new URL for the GeoJSON data.

The returned Future completes with true if the source was successfully updated, false otherwise.

Implementation

Future<bool> editGeoJsonUrl(String id, String url) async {
  return _maplibrePlatform.editGeoJsonUrl(id, url);
}