IMDFConverter class

Utility to convert between PowerMap internal GeoJSON format and OGC IMDF (20-094) standard.

Constructors

IMDFConverter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromIMDF(Map<String, dynamic> imdfCollection) Future<Map<String, dynamic>>
Transforms IMDF format back to PowerMap internal format.
toIMDF(Map<String, dynamic> featureCollection) Future<Map<String, dynamic>>
Transforms internal features to IMDF format.

Constants

mapping → const Map<String, Map<String, String>>
Map SDK internal 'kind' to OGC IMDF 'feature_type' and 'category'.