ClusterManager class

Manage high-performance marker clustering using native MapLibre GeoJSON sources and layers.

Constructors

ClusterManager(MapLibreMapController _controller)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearClusters() Future<void>
Clears all clustered points and removes layers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPoints(List<LatLng> points) Future<void>
Updates the map with a new list of points to be clustered.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

clusterLayerId → const String
countLayerId → const String
sourceId → const String
unclusteredLayerId → const String