SearchManager class
Manager for handling search and geocoding requests with caching and debouncing.
Constructors
- SearchManager({required GeocodingProvider provider})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- provider → GeocodingProvider
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
autocompleteDebounced(
String query, Duration delay, dynamic onResult(List< PowerMapSearchResult> ), {LatLng? location, String lang = 'auto'}) → void - Debounced autocomplete for search-as-you-type
-
clearCache(
) → void - Clears internal cache
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reverseGeocode(
LatLng location, {String lang = 'auto'}) → Future< PowerMapSearchResult?> - Reverse geocode coordinates to an address
-
search(
String query, {LatLng? location, String lang = 'auto'}) → Future< List< PowerMapSearchResult> > -
Searches for places matching the
query. -
searchByCategory(
String categoryId, LatLng location, {int dist = 5, String lang = 'auto'}) → Future< List< PowerMapSearchResult> > - Searches for places nearby by category ID (e.g. '2100' = Restaurant)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited