PowerMapRouteResult class

Constructors

PowerMapRouteResult({required double distance, required double duration, required List<LatLng> geometry, required List<PowerRouteStep> steps, required Map<String, dynamic> raw, String profile = 'driving'})

Properties

distance double
final
distanceStr String
no setter
duration double
final
durationStr String
no setter
geometry List<LatLng>
final
hashCode int
The hash code for this object.
no setterinherited
profile String
final
raw Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<PowerRouteStep>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited