PowerMapSearchResult class
Represents a result from the PowerMap Search/Geocoding API.
Constructors
-
PowerMapSearchResult({required int gid, required String name, String nameEn = '', String nameTh = '', required String address, String addressEn = '', String addressTh = '', required LatLng position, String province = '', String amphoe = '', String tambon = '', String postCode = '', Map<
String, dynamic> rawData = const {}}) -
PowerMapSearchResult.fromJson(Map<
String, dynamic> json, {String lang = 'auto', String query = ''}) -
factory
Properties
- address → String
-
final
- addressEn → String
-
final
- addressTh → String
-
final
- amphoe → String
-
final
- gid → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- nameEn → String
-
final
- nameTh → String
-
final
- position → LatLng
-
final
- postCode → String
-
final
- province → String
-
final
-
rawData
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tambon → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited