SpeedLimitResult class
Represents the speed limit result returned by PowerMap Speed Limit API.
Constructors
Properties
- debugCached → bool?
-
Whether the API response was served from cache.
final
- distM → double?
-
Distance in meters to the matched road feature.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → LatLng?
-
Original query input position.
final
- ogcFid → int?
-
Feature ID in the GIS database representing the road segment.
final
-
raw
→ Map<
String, dynamic> ? -
Raw json map from response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double?
-
The legal speed limit in km/h (e.g. 120, 90, 80, 50).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts model back to JSON map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited