TileService class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearCache(
) → Future< void> - Clears all cached styles (memory + disk).
-
getOptimizedStyleJson(
String name, {bool enable3D = false}) → Future< String> - Fetches, optimizes, and caches the style JSON.
-
getStyleUrl(
String name) → String -
Returns the complete style URL for MapLibre based on the given style
name.