IconUtil class
Constructors
- IconUtil()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createBitmapFromIcon(
{required IconData icon, required Color color, required double size}) → Future< Uint8List> - Converts a Flutter IconData into a PNG byte array that MapLibre can render natively. Draws a colored rounded rectangle with a white border, drop shadow, and white icon.
-
getIconData(
String name) → IconData - Maps a string name to its corresponding IconData dynamically
-
parseColor(
String hexColor, {Color defaultColor = Colors.black}) → Color - Parses a hex color string to a Color object.